@@ -46,13 +46,6 @@
 
 #include "config.h"
 
-#ifndef HAVE_PKG_HASH_ITER_NEW
-#define pkg_hash_iter		pkgiterator
-#define pkg_hash_iter_new	pkg_db_iter_new
-#define pkg_hash_iter_next_pkg	pkg_db_iter_next_pkg
-#define pkg_hash_iter_free	pkg_db_iter_free
-#endif
-
 int audit_mode = 1;
 int rectify_mode = 0;
 int report_mode = 0;
@@ -60,9 +53,6 @@ int deptrace_mode = 0;
 int delete_tmpdir_mode = 1;
 int print_usage = 0;
 int print_version = 0;
-#ifndef HAVE_DPKG_SET_PROGNAME
-const char thisname[] = "luau";
-#endif /* HAVE_DPKG_SET_PROGNAME */
 
 static int
 dpkg_status (lua_State * L)
@@ -87,39 +77,7 @@ dpkg_status (lua_State * L)
 	  lua_error (L);
 	}
 
-#ifdef HAVE_PKG_STATUS_NAME
       lua_pushstring (L, pkg_status_name (p));
-#else
-      switch (p->status)
-	{
-	case stat_notinstalled:
-	  lua_pushstring (L, "not-installed");
-	  break;
-	case stat_configfiles:
-	  lua_pushstring (L, "config-files");
-	  break;
-	case stat_halfinstalled:
-	  lua_pushstring (L, "half-installed");
-	  break;
-	case stat_unpacked:
-	  lua_pushstring (L, "unpacked");
-	  break;
-	case stat_halfconfigured:
-	  lua_pushstring (L, "half-configured");
-	  break;
-	case stat_triggersawaited:
-	  lua_pushstring (L, "triggers-awaited");
-	  break;
-	case stat_triggerspending:
-	  lua_pushstring (L, "triggers-pending");
-	  break;
-	case stat_installed:
-	  lua_pushstring (L, "installed");
-	  break;
-	default:
-	  lua_pushinteger (L, p->status);
-	}
-#endif
       j++;
     }
   return j;
@@ -401,9 +359,7 @@ main (int argc, char **argv)
   fprintf (stderr, "under certain conditions.\n");
 
   push_error_context ();
-#ifdef HAVE_DPKG_SET_PROGNAME
   dpkg_set_progname("luau");
-#endif /* HAVE_DPKG_SET_PROGNAME */
 
   modstatdb_open (msdbrw_readonly); /* Use default dpkg db directory. */
 
